@@ -8,8 +8,8 @@ r = RequestsClient()
 
 class Client(unittest.TestCase):
     def test_get(self):
-        self.assertTrue(r.get('https://1.1.1.1'))
-        self.assertTrue(r.requests.get('https://1.1.1.1'))
+        r.get('https://1.1.1.1')
+        r.requests.get('https://1.1.1.1')
         self.assertFalse(r.get('x://127.0.0.1'))
 
 
